Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4520)

Unified Diff: sync/test/engine/syncer_command_test.cc

Issue 10832286: sync: Introduce control data types (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sync/test/engine/syncer_command_test.cc
diff --git a/sync/test/engine/syncer_command_test.cc b/sync/test/engine/syncer_command_test.cc
index 2439c1ba2c305744d42c1bf3a58bbab89e77e8a6..147431f8e85854b6cd65a1680694fd1162b70874 100644
--- a/sync/test/engine/syncer_command_test.cc
+++ b/sync/test/engine/syncer_command_test.cc
@@ -18,9 +18,11 @@ SyncerCommandTestBase::~SyncerCommandTestBase() {
void SyncerCommandTestBase::SetUp() {
ResetContext();
// The session always expects there to be a passive worker.
workers()->push_back(
make_scoped_refptr(new FakeModelWorker(GROUP_PASSIVE)));
+ workers()->push_back(
+ make_scoped_refptr(new FakeModelWorker(GROUP_CONTROL)));
}
void SyncerCommandTestBase::TearDown() {
@@ -56,6 +58,8 @@ void MockDirectorySyncerCommandTest::SetUp() {
// The session always expects there to be a passive worker.
workers()->push_back(
make_scoped_refptr(new FakeModelWorker(GROUP_PASSIVE)));
+ workers()->push_back(
+ make_scoped_refptr(new FakeModelWorker(GROUP_CONTROL)));
ResetContext();
}
« sync/internal_api/public/base/model_type.h ('K') | « sync/test/engine/syncer_command_test.h ('k') | no next file » | no next file with comments »
@@ -18,9 +18,11 @@ SyncerCommandTestBase::~SyncerCommandTestBase() {
void SyncerCommandTestBase::SetUp() {
ResetContext();
- // The session always expects there to be a passive worker.
+ // The session always expects there to be passive and control workers.
workers()->push_back(
make_scoped_refptr(new FakeModelWorker(GROUP_PASSIVE)));

Powered by Google App Engine
This is Rietveld 408576698